Box3dRayHit class

A hit from a ray cast or shape cast. shape is the packed shape handle (compare against a Box3dShape.handle).

Constructors

Box3dRayHit({required int shape, required Vector3 point, required Vector3 normal, required double fraction, required double distance})

Properties

distance double
Distance from the cast origin to the hit, in world units.
final
fraction double
Fraction along the cast (0 at the origin, 1 at the far end) where the hit occurred.
final
hashCode int
The hash code for this object.
no setterinherited
normal → Vector3
World-space surface normal at the hit.
final
point → Vector3
World-space hit point.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited