Box3dEvents class
All events collected during one Box3dWorld.step, drained together.
Constructors
-
Box3dEvents({required List<
Box3dContactBegan> contactBegan, required List<Box3dContactEnded> contactEnded, required List<Box3dSensorBegan> sensorBegan, required List<Box3dSensorEnded> sensorEnded})
Properties
-
contactBegan
→ List<
Box3dContactBegan> -
final
-
contactEnded
→ List<
Box3dContactEnded> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether any event of any kind occurred.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sensorBegan
→ List<
Box3dSensorBegan> -
final
-
sensorEnded
→ List<
Box3dSensorEnded> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited